FlatVec

Type Alias FlatVec 

pub type FlatVec<T, L = usize> = GenericVec<[MaybeInvalid<T>], L>;
Growable flat vector of sized items.

It doesn’t allocate memory on the heap but instead stores its contents in the same memory behind itself.

Obviously, this type is DST.

Aliased Type

pub struct FlatVec<T, L = usize> { /* private fields */ }